Droppable Visual Test - Droppable ticket 4088

# Ticket #4088 - Unable to remove() ui.draggable (sortable item) immediately after the drop callback.

## TEST: Drag 'Special Item' to the div labelled 'Drop here'

## TEST: Drag a 'Normal Item' to the div labelled 'Drop here'

- Special Item
- Normal Item 1
- Normal Item 2
- Normal Item 3

#### Trash Drop here

### ASSERT: The dropped item is removed from the original list and the following text does not appear: "I was dropped and removed, but still here I am!"